        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,6,7,9,11,14,15,17,20,24,25,26,27,28,29,30,32,33,37,40,41,42,44,46,49,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>1,5,10,13,16,18,21,23,35,38,39,45,47,48';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 9 <br>4,8,12,19,22,31,34,36,43';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,6,7,9,11,14,15,17,20,24,25,26,27,28,29,30,32,33,37,40,41,42,44,46,49,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>1,5,10,13,16,18,21,23,35,38,39,45,47,48';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 9 <br>4,8,12,19,22,31,34,36,43';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,6,7,9,11,14,15,17,20,24,25,26,27,28,29,30,32,33,37,40,41,42,44,46,49,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>1,5,10,13,16,18,21,23,35,38,39,45,47,48';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 9 <br>4,8,12,19,22,31,34,36,43';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,6,7,9,11,14,15,17,20,24,25,26,27,28,29,30,32,33,37,40,41,42,44,46,49,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>1,5,10,13,16,18,21,23,35,38,39,45,47,48';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 9 <br>4,8,12,19,22,31,34,36,43';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,6,7,9,11,14,15,17,20,24,25,26,27,28,29,30,32,33,37,40,41,42,44,46,49,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>1,5,10,13,16,18,21,23,35,38,39,45,47,48';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 9 <br>4,8,12,19,22,31,34,36,43';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,6,7,9,11,14,15,17,20,24,25,26,27,28,29,30,32,33,37,40,41,42,44,46,49,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>1,5,10,13,16,18,21,23,35,38,39,45,47,48';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260604 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>8</strong> miembros: 9 <br>4,8,12,19,22,31,34,36,43';}
}
